$(document).ready(function() {
    /* Load config */
    $.getJSON('main.config.json', function(data) {
        var config = data;

        /* Countdown */
        var date = new Date(config.countdown.year, config.countdown.month - 1, config.countdown.day, config.countdown.hours, config.countdown.minutes, config.countdown.seconds);
        var $countdown = $('#countdown');

        $countdown.countdown(date, function(event) {
            /* Animation */
            function setDate(type, value) {
                var $container = $('.' + type, $countdown);
                var $old_number = $('.countdown-number', $container);
                var $new_number = $('<div class="countdown-number">' + value + '</div>');

                $new_number.prependTo($container).css({
                    'position': 'absolute',
                    'top': -$new_number.height(),
                    'left': 0
                });

                var container_height = $container.height();
                var number_height = $new_number.height();

                $old_number.animate({
                    'top': '+=' + (container_height + number_height) / 2
                }, 500, function() {
                    $old_number.remove();
                });

                $new_number.animate({
                    'top': (container_height - number_height) / 2
                }, 500);
            }

            switch(event.type) {
                case "seconds":
                case "minutes":
                case "hours":
                case "days":
                case "weeks":
                case "daysLeft":
                    if($('body').hasClass('countdown-animated')) {
                        setDate(event.type, event.value)
                    } else {
                        $('.' + event.type, $countdown).text(event.value);
                    }

                    break;

                case "finished":
                    $countdown.text('LAUNCHED');
                    break;
            }
        });

        /* Subscription form */

        var messages = config.subscription;

        $('#subscribe').submit(function(event) {
            event.preventDefault();

            var error = false;
            var $form = $(this);
            var $email = $('#subscribe-email');
            var $button = $('#subscribe-submit');
            var email = $email.val();
            var $tooltip = $('#subscribe-tooltip');

            if($tooltip.length == 0) {
                $tooltip = $('<p id="subscribe-tooltip"></p>');
            }

            if(email.length == 0) {
                $tooltip.text(messages['empty_email']).addClass('error').appendTo($form);
            }
            else {
                $button.attr('disabled', 'disabled');

                $.post('subscribe.php', {
                    'email': email,
                    'ajax': 1
                },
                function(data) {
                    if(data == null || typeof(data.status) == 'undefined' || (data.status == 'error' && typeof(data.error) == 'undefined')) {
                        $tooltip.text(messages['default']).addClass('error').appendTo($form);
                    }
                    else if(data.status == 'success') {
                        $tooltip.text(messages['success']).addClass('success').appendTo($form);
                    }
                    else {
                        var error_text = messages['default_error'];

                        switch(data.error) {
                            case 'empty_email':
                            case 'invalid_email':
                                error_text = messages[data.error];
                                break;
                        }

                        $tooltip.text(error_text).addClass('error').appendTo($form);
                    }

                    $button.removeAttr('disabled');
                },
                'json');
            }
        });

        // Remove tooltip on text change
        $('#subscribe-email').on('change focus click keyup', function() {
            if($(this).val().length > 0)
            {
                $('#subscribe-tooltip').remove();
            }
        });
    });
});